==> work-runtime-2.8.0-beta01-sources.jar: androidx/work/impl/model/SystemIdInfo.kt <==
/*
 * Copyright 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package androidx.work.impl.model

import androidx.annotation.RestrictTo
import androidx.room.ColumnInfo
import androidx.room.Entity
import androidx.room.ForeignKey

/**
 * Stores system ids for a [WorkSpec] id.
 *
 * @hide
 */
@Entity(
    foreignKeys = [ForeignKey(
        entity = WorkSpec::class,
        parentColumns = ["id"],
        childColumns = ["work_spec_id"],
        onDelete = ForeignKey.CASCADE,
        onUpdate = ForeignKey.CASCADE
    )],
    primaryKeys = ["work_spec_id", "generation"]
)
@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
data class SystemIdInfo(
    @JvmField
    @ColumnInfo(name = "work_spec_id")
    val workSpecId: String,

    @ColumnInfo(defaultValue = "0")
    val generation: Int,

    @JvmField
    @ColumnInfo(name = "system_id")
    val systemId: Int
)

fun systemIdInfo(generationalId: WorkGenerationalId, systemId: Int) =
    SystemIdInfo(generationalId.workSpecId, generationalId.generation, systemId)

==> work-runtime-2.10.0-beta01-sources.jar: androidx/work/impl/model/SystemIdInfo.kt <==
/*
 * Copyright 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package androidx.work.impl.model

import androidx.annotation.RestrictTo
import androidx.room.ColumnInfo
import androidx.room.Entity
import androidx.room.ForeignKey

/** Stores system ids for a [WorkSpec] id. */
@Entity(
    foreignKeys =
        [
            ForeignKey(
                entity = WorkSpec::class,
                parentColumns = ["id"],
                childColumns = ["work_spec_id"],
                onDelete = ForeignKey.CASCADE,
                onUpdate = ForeignKey.CASCADE
            )
        ],
    primaryKeys = ["work_spec_id", "generation"]
)
@RestrictTo(RestrictTo.Scope.LIBRARY_GROUP)
data class SystemIdInfo(
    @JvmField @ColumnInfo(name = "work_spec_id") val workSpecId: String,
    @ColumnInfo(defaultValue = "0") val generation: Int,
    @JvmField @ColumnInfo(name = "system_id") val systemId: Int
)

fun systemIdInfo(generationalId: WorkGenerationalId, systemId: Int) =
    SystemIdInfo(generationalId.workSpecId, generationalId.generation, systemId)
